Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/netbsd-1-4]: src/sys/dev A more consistent branch-specific fix for the d...



details:   https://anonhg.NetBSD.org/src/rev/423b53a65901
branches:  netbsd-1-4
changeset: 469254:423b53a65901
user:      he <he%NetBSD.org@localhost>
date:      Sun Aug 22 16:33:48 1999 +0000

description:
A more consistent branch-specific fix for the data extraction locking bug
previously fixed.  Patch from ross.

diffstat:

 sys/dev/rnd.c |  14 +++++++-------
 1 files changed, 7 insertions(+), 7 deletions(-)

diffs (63 lines):

diff -r f9bca118f426 -r 423b53a65901 sys/dev/rnd.c
--- a/sys/dev/rnd.c     Sun Aug 22 16:26:00 1999 +0000
+++ b/sys/dev/rnd.c     Sun Aug 22 16:33:48 1999 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: rnd.c,v 1.15.2.2 1999/08/08 07:04:16 cgd Exp $ */
+/*     $NetBSD: rnd.c,v 1.15.2.3 1999/08/22 16:33:48 he Exp $  */
 
 /*-
  * Copyright (c) 1997 The NetBSD Foundation, Inc.
@@ -378,7 +378,7 @@
                         * How much entropy do we have?  If it is enough for
                         * one hash, we can read.
                         */
-                       s = splsoftclock();
+                       s = splsoftnet();
                        entcnt = rndpool_get_entropy_count(&rnd_pool);
                        splx(s);
                        if (entcnt >= RND_ENTROPY_THRESHOLD * 8)
@@ -448,7 +448,7 @@
                /*
                 * Mix in the bytes.
                 */
-               s = splsoftclock();
+               s = splsoftnet();
                rndpool_add_data(&rnd_pool, buf, n, 0);
                splx(s);
 
@@ -490,7 +490,7 @@
                break;
 
        case RNDGETENTCNT:
-               s = splsoftclock();
+               s = splsoftnet();
                *(u_int32_t *)addr = rndpool_get_entropy_count(&rnd_pool);
                splx(s);
 
@@ -607,7 +607,7 @@
 
                rnddata = (rnddata_t *)addr;
 
-               s = splsoftclock();
+               s = splsoftnet();
                rndpool_add_data(&rnd_pool, rnddata->data, rnddata->len,
                                 rnddata->entropy);
 
@@ -655,7 +655,7 @@
        /*
         * make certain we have enough entropy to be readable
         */
-       s = splsoftclock();
+       s = splsoftnet();
        entcnt = rndpool_get_entropy_count(&rnd_pool);
        splx(s);
 
@@ -876,7 +876,7 @@
 
 /*
  * timeout, run to process the events in the ring buffer.  Only one of these
  * can possibly be running at a time, and we are run at splsoftclock().
  */
 static void
 rnd_timeout(arg)
@@ -876,7 +876,7 @@
 /*
  * timeout, run to process the events in the ring buffer.  Only one of these
- * can possibly be running at a time, and we are run at splsoftclock().
+ * can possibly be running at a time, and we are run at splsoftnet().
  */
 static void



Home | Main Index | Thread Index | Old Index